// -----------------------------------------------------------------------------
//
// Author(s):     Peter Schraut (www.console-dev.de)
// Last Modified: 19th June 2007
//
// Purpose:       Demo shows how to use call-stack-trace feature
//
// Notes:
//                See makefile for neccessary compiler flags.
//                Please notice the call-stack-trace feature
//                makes the program execution very slow, I recommend
//                to use this feature only when you really do need a callstack.
//
// -----------------------------------------------------------------------------
#include <hel2.h>


// -----------------------------------------------------------------------------
// Prototypes
// -----------------------------------------------------------------------------

void ATTR_NOINLINE Game_Update(void);
void ATTR_NOINLINE GameObjectHandler_Update(void);
void ATTR_NOINLINE Player_Update(void);
void ATTR_NOINLINE Player_UpdateCollision(const void* pNoNullPointer);


// -----------------------------------------------------------------------------
// Program Entry Point
// -----------------------------------------------------------------------------
int main(void)
{
	ham_Init();
	hel_SysSetPrefetch(TRUE);

	Game_Update();

	return 0;
}

// -----------------------------------------------------------------------------
// FirstFunction
// -----------------------------------------------------------------------------
void ATTR_NOINLINE Game_Update(void)
{
	GameObjectHandler_Update();
}

// -----------------------------------------------------------------------------
// SecondFunction
// -----------------------------------------------------------------------------
void ATTR_NOINLINE GameObjectHandler_Update(void)
{
	Player_Update();
}

// -----------------------------------------------------------------------------
// ThirdFunction
// -----------------------------------------------------------------------------
void ATTR_NOINLINE Player_Update(void)
{
	Player_UpdateCollision(NULL);
}

// -----------------------------------------------------------------------------
// FourthFunction
// -----------------------------------------------------------------------------
void ATTR_NOINLINE Player_UpdateCollision(const void* pNoNullPointer)
{
	HEL_ASSERT(pNoNullPointer != NULL, "pNoNullPointer must not be null.");
}
