// -----------------------------------------------------------------------------
//
// Author(s):     Peter Schraut (www.console-dev.de)
// Last Modified: 10th August 2006
//
// Purpose:       Demo shows how to use the Splash-Screen System
//                conjunction with a LZ77 compressed graphic and palette.
//
// Note:
//                Please take a look at the makefile, since the
//                graphic conversion commandline has been extended.
//                See HEL-FAQ for GBACrusherCL.exe
//
// -----------------------------------------------------------------------------
#include <hel2.h>
#include "ResourceData.h"

// Workmemory for Splash-Screen System
u8 ATTR_EWRAM ATTR_ALIGNED(4) g_SplashScreenSystemBuffer[HEL_SUBSYSTEM_SPLASH_REQUIREDMEMORY];


// -----------------------------------------------------------------------------
// Program Entry Point
// -----------------------------------------------------------------------------
int main(void)
{
    ham_Init();
    hel_SysSetPrefetch(TRUE);
    ham_SetBgMode(4);
    
    // Initialize Splash-Screen System
    hel_SplashInit((void*)g_SplashScreenSystemBuffer);

    for(;;)
    {
      // Display the SplashScreen
      // Delays specified in milli-seconds (not very accurate)
      hel_Splash
         (
             ResData(RES_SPLASHHEL_RAW_LZ77),   // pBitmap
             ResData(RES_SPLASHHEL_PAL_LZ77),   // pPalette
             RGB(0,0,0),                        // InBlendColor
             RGB(0,0,0),                        // OutBlendColor
             60,                                // BlendDelay
             2000,                              // DisplayDelay
             500,                               // ContinueDelay
             COMPRESSION_TYPE_LZ77VRAM,         // CompressionType,
             0                                  // Flags
         );
    }
    
    // Uninitialize Splash-Screen System
    hel_SplashQuit();
    
    return 0;
}


